@@ -123,6 +123,7 @@ typedef struct
    HashType hashkey;
    HashType phashkey;
    char SANmv[SANSZ];  /* The move in SAN notation */
+   char *comments;
 } GameRec;
 
 typedef struct
@@ -162,7 +163,9 @@ typedef struct
     (a) &= ~(b);                     \
     dbg_printf("Clear 0x%x\n", (b)); \
   } while (0)
-#define	DRAWSCORE    (computerplays == board.side ? (opprating - myrating) / 4 : (myrating - opprating ) / 4)
+
+/* Draw score can be used to penalise draws if desired */
+#define	DRAWSCORE   0 
 #define MATERIAL     (board.material[side] - board.material[1^side])
 #define PHASE	     (8 - (board.material[white]+board.material[black]) / 1150)
 #define KEY(a)	     (a >> 32) 
@@ -273,7 +276,7 @@ typedef struct
 #define THINK   0x0004
 #define MANUAL  0x0008
 #define TIMEOUT 0x0010
-#define DEBUGG  0x0020
+#define SPARE1  0x0020
 #define ENDED   0x0040
 #define USEHASH 0x0080
 #define SOLVE   0x0100
@@ -327,8 +330,6 @@ typedef struct
 #define HASHSLOTS 1024 
 #define PAWNSLOTS 512
 
-#define DEPTH	12
-
 extern short distance[64][64];
 extern short taxicab[64][64];
 extern unsigned char lzArray[65536];
@@ -441,9 +442,6 @@ extern float TCTime;
 extern int hunged[2];
 extern int phase;
 extern int Hashmv[MAXPLYDEPTH];
-extern int Debugmv[MAXPLYDEPTH];
-extern short Debugmvl;
-extern short Debugline;
 extern short RootPieces;
 extern short RootPawns;
 extern short RootMaterial;
@@ -452,8 +450,6 @@ extern short RootBeta;
 extern short pickphase[MAXPLYDEPTH];
 extern short InChk[MAXPLYDEPTH];
 extern short KingThrt[2][MAXPLYDEPTH];
-extern short threatmv;
-extern uint8_t threatply;
 extern short KingSafety[2];
 extern short pscore[64];
 
@@ -477,7 +473,7 @@ extern int rank6[2];
 extern int rank7[2];
 extern int rank8[2];
 
-extern const char *progname;
+extern char *progname;
 extern FILE *ofp;
 extern int myrating, opprating, suddendeath;
 
@@ -539,6 +535,7 @@ void InitDistance (void);
 void InitVars (void);
 void InitHashCode (void);
 void InitHashTable (void);
+void CalcHashSize (int);
 void NewPosition (void);
 void InitFICS (void);
 void InitInput (void);
@@ -547,7 +544,6 @@ void InitInput (void);
 void CleanupInput(void);
 
 /*  The book routines */
-void MakeBinBook (char *, short);
 int BookQuery (int);
 int BookBuilderOpen(void);
 int BookBuilder (short result, uint8_t side);
@@ -623,6 +619,8 @@ short ValidateBoard (void);
 void PGNSaveToFile (const char *, const char *);
 void PGNReadFromFile (const char *);
 void BookPGNReadFromFile (const char *);
+int IsTrustedPlayer(const char *name);
+
 
 /*  The hash routines  */
 void CalcHashKey (void);
@@ -707,10 +705,6 @@ void TestCaptureList (void);
 void TestEvalSpeed (void);
 void TestEval (void);
 
-/*  Miscellaneous routines  */
-void ShowVersion (void);
-void ShowHelp (const char *);
-
 /* Player database */
 void DBSortPlayer (const char *style);
 void DBListPlayer (const char *style); 	
@@ -775,10 +769,6 @@ void cmd_bk(void);
 void cmd_black(void);
 void cmd_book(void);
 void cmd_computer(void);
-void cmd_debug(void);
-void cmd_debugdepth(void);
-void cmd_debugnode(void);
-void cmd_debugply(void);
 void cmd_depth(void);
 void cmd_draw(void);
 void cmd_easy(void);
